@@ -12,7 +12,7 @@ use YAML::PP;
 use Capture::Tiny ':all';
 use File::Basename;
 
-$Qiime2::Artifact::VERSION = '0.10.3';
+$Qiime2::Artifact::VERSION = '0.10.5';
 
 sub crash($);
 
@@ -137,7 +137,7 @@ sub _read_artifact {
   $self->{version} = $1 if ($root_version=~/framework:\s*\"?(.+)\"?/);
   $self->{archive} = $1 if ($root_version=~/archive:\s*\"?(.+)\"?/);
   $self->{loaded} = 1;
-  $self->{parents} = (scalar keys %{ $self->{parents} })-1;
+  $self->{parents_number} = scalar( keys %{ $self->{parents} } ) - 1  ;
 
 }
 
@@ -221,6 +221,11 @@ sub _check_output {
   # check if a command has a string in the output
   my ($cmd, $pattern) = @_;
   my $output = _run($cmd);
+
+  if ($output->{status} != 0) {
+      crash("Unable to test <$cmd>, execution returned $output->{status}");
+  }
+
   if ($output->{stdout} =~/$pattern/) {
     return 1;
   } elsif ($output->{stderr} =~/$pattern/) {
@@ -335,7 +340,7 @@ Qiime2::Artifact - A parser for Qiime2 artifact files
 
 =head1 VERSION
 
-version 0.10.3
+version 0.10.5
 
 =head1 Synopsis
 
